<?php

namespace Farabi\Portal\Http\Controllers;

use App\Http\Controllers\PublicApiController as PublicController;
use Farabi\Portal\Interfaces\EntranceRepositoryInterface;
use Farabi\Portal\Repositories\Presenter\EntranceItemTransformer;

/**
 * Pubic API controller class.
 */
class EntrancePublicApiController extends PublicController
{
    /**
     * Constructor.
     *
     * @param type \Farabi\Entrance\Interfaces\EntranceRepositoryInterface $entrance
     *
     * @return type
     */
    public function __construct(EntranceRepositoryInterface $entrance)
    {
        $this->repository = $entrance;
        parent::__construct();
    }

    /**
     * Show entrance's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $entrances = $this->repository
            ->setPresenter('\\Farabi\\Portal\\Repositories\\Presenter\\EntranceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $entrances['code'] = 2000;
        return response()->json($entrances)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show entrance.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $entrance = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($entrance)) {
            $entrance         = $this->itemPresenter($module, new EntranceItemTransformer);
            $entrance['code'] = 2001;
            return response()->json($entrance)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
