<?php

namespace Farabi\Portal\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Farabi\Portal\Models\Entrance;

class EntrancePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the entrance.
     *
     * @param User $user
     * @param Entrance $entrance
     *
     * @return bool
     */
    public function view(User $user, Entrance $entrance)
    {
        if ($user->canDo('portal.entrance.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $entrance->user_id;
    }

    /**
     * Determine if the given user can create a entrance.
     *
     * @param User $user
     * @param Entrance $entrance
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('portal.entrance.create');
    }

    /**
     * Determine if the given user can update the given entrance.
     *
     * @param User $user
     * @param Entrance $entrance
     *
     * @return bool
     */
    public function update(User $user, Entrance $entrance)
    {
        if ($user->canDo('portal.entrance.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $entrance->user_id;
    }

    /**
     * Determine if the given user can delete the given entrance.
     *
     * @param User $user
     * @param Entrance $entrance
     *
     * @return bool
     */
    public function destroy(User $user, Entrance $entrance)
    {
        if ($user->canDo('portal.entrance.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $entrance->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
